@@ -10,11 +10,11 @@ import websocket
 from apscheduler.schedulers.blocking import BlockingScheduler
 from notecoin.huobi.constant import *
 from notecoin.huobi.constant import ApiVersion
-from notecoin.huobi.exception.huobi_api_exception import HuobiApiException
-from notecoin.huobi.model import Response
 from notecoin.huobi.utils import *
 from notecoin.huobi.utils.api_signature import create_signature_v2
 from notecoin.huobi.utils.etf_result import etf_result_check
+from notecoin.huobi.utils.huobi_api_exception import HuobiApiException
+from notecoin.huobi.utils.model import Response
 from notecoin.huobi.utils.print_mix_object import TypeCheck
 from notecoin.huobi.utils.time_service import get_current_timestamp
 from notecoin.huobi.utils.url_params_builder import UrlParamsBuilder
