@@ -95,8 +95,19 @@ class TradeUpdate:
         self.kline_1mon.auto_save()
         self.kline_1week.auto_save()
         self.kline_1year.auto_save()
+    def _save(self):
+        self.tradeDB._sa()
+        self.kline_1min.auto_save()
+        self.kline_5min.auto_save()
+        self.kline_15min.auto_save()
+        self.kline_30min.auto_save()
+        self.kline_4hour.auto_save()
+        self.kline_1day.auto_save()
+        self.kline_1mon.auto_save()
+        self.kline_1week.auto_save()
+        self.kline_1year.auto_save()
 
-    def insert_trades(self, trade=True, kline=True):
+    def insert_data(self, trade=True, kline=True):
         symbols = self.symbolDB.select("select symbol from {} where state ='online'".format(self.symbolDB.table_name))
         for symbol in tqdm(symbols):
             try:
@@ -126,10 +137,12 @@ class TradeUpdate:
         while True:
             self.insert_symbol()
             if t % 100 == 0:
-                self.insert_trades(trade=True, kline=True)
+                self.insert_data(trade=True, kline=True)
+                self.auto_save()
+            elif t % 10 == 0:
                 self.auto_save()
             else:
-                self.insert_trades(trade=True, kline=False)
+                self.insert_data(trade=True, kline=False)
                 t += 1
                 time.sleep(60)
 
